#!/usr/bin/python3
# -*- coding: utf-8 -*-
from PyQt5.QtCore import *
from PyQt5.QtGui import *
from PyQt5.QtWidgets import QWidget, QTextEdit, QVBoxLayout, QDesktopWidget

from mainui.systembutton import *
from mainui.titlebar import *

import gettext

gettext.textdomain("kylin-update-manager")

_ = gettext.gettext


class AboutWidget(QWidget):
    m_parent = None

    def __init__(self, parent=None):

        self.m_parent = parent
        super(AboutWidget, self).__init__(parent)
        self.mouse_press = False
        self.initui()
        self.init_connect()

    # 初始化关于界面
    def initui(self):
        self.setFixedSize(450, 320)
        self.setWindowFlags(Qt.FramelessWindowHint | Qt.Tool)

        palette = QPalette()
        palette.setColor(QPalette.Background, QColor(255, 255, 255))
        self.setPalette(palette)

        self.text_box = QTextEdit(self)
        self.text_box.setTextInteractionFlags(Qt.NoTextInteraction)
        self.text_box.setFrameShape(QFrame.NoFrame)
        self.text_box.move(0, 0)
        self.text_box.setFixedWidth(400)
        self.text_box.setReadOnly(True)
        self.text_box.setStyleSheet("QTextEdit{color:#444444;font-size:12px;}")
        self.text_box.verticalScrollBar().setStyleSheet("QScrollBar:vertical{margin:0px 0px 0px 0px;background-color:rgb(255,255,255,100);border:0px;width:6px;border-radius:6px;}\
                                                                             QScrollBar::sub-line:vertical{subcontrol-origin:margin;border:0px solid red;height:13px}\
                                                                             QScrollBar::up-arrow:vertical{subcontrol-origin:margin;background-color:rgba(0,0,0,0);height:13px}\
                                                                             QScrollBar::sub-page:vertical{background-color:#EEEDF0;}\
                                                                             QScrollBar::handle:vertical{background-color:rgba(0,0,0,20%);width:6px;border-radius:6px;}\
                                                                             QScrollBar::handle:vertical:hover{background-color:rgb(0,0,0,10%);opacity:0.1;width:6px;border-radius:6px;}\
                                                                             QScrollBar::handle:vertical:pressed{background-color:rgb(0,0,0,50%);width:6px;border-radius:6px;}\
                                                                             QScrollBar::add-page:vertical{background-color:#EEEDF0;}\
                                                                             QScrollBar::down-arrow:vertical{background-color:rgba(0,0,0,0);}\
                                                                             QScrollBar::add-line:vertical{subcontrol-origin:margin;border:0px solid green;height:13px}")
        self.text_company = QTextEdit(self)
        self.text_company.setFixedWidth(400)
        self.text_company.setReadOnly(True)
        self.text_company.setStyleSheet("QTextEdit{color:#444444;font-size:12px;border:none;}")
        self.text_company.verticalScrollBar().setStyleSheet("QScrollBar:vertical{margin:0px 0px 0px 0px;background-color:rgb(255,255,255,100);border:0px;width:6px;border-radius:6px;}\
                                                                             QScrollBar::sub-line:vertical{subcontrol-origin:margin;border:0px solid red;height:13px}\
                                                                             QScrollBar::up-arrow:vertical{subcontrol-origin:margin;background-color:rgba(0,0,0,0);height:13px}\
                                                                             QScrollBar::sub-page:vertical{background-color:#EEEDF0;}\
                                                                             QScrollBar::handle:vertical{background-color:rgba(0,0,0,20%);width:6px;border-radius:6px;}\
                                                                             QScrollBar::handle:vertical:hover{background-color:rgb(0,0,0,10%);opacity:0.1;width:6px;border-radius:6px;}\
                                                                             QScrollBar::handle:vertical:pressed{background-color:rgb(0,0,0,50%);width:6px;border-radius:6px;}\
                                                                             QScrollBar::add-page:vertical{background-color:#EEEDF0;}\
                                                                             QScrollBar::down-arrow:vertical{background-color:rgba(0,0,0,0);}\
                                                                             QScrollBar::add-line:vertical{subcontrol-origin:margin;border:0px solid green;height:13px}")

        self.label_img = QLabel(self)
        self.label_img.move(25, 25)
        self.label_img.setFixedSize(64, 64)
        self.label_img.setFrameShape(QFrame.NoFrame)
        self.label_img.setAutoFillBackground(True)
        self.label_img.setScaledContents(True)
        pixmap_img = QPixmap("./res/kylin-update-manager.png")
        self.label_img.setPixmap(pixmap_img)

        self.label_text = QLabel(self)
        self.label_text.setText(_("Kylin Update Manager"))
        self.label_text.setStyleSheet("QLabel{color:#444444;font-size:24px;}")

        self.close_button = SystemButton(False, False, True, self)
        self.close_button.move(self.width() - 34, 4)

        hlayout = QHBoxLayout()
        hlayout.addSpacing(25)
        hlayout.addWidget(self.label_img)
        hlayout.addSpacing(10)
        hlayout.addWidget(self.label_text)
        hlayout.addStretch()

        hlayout2 = QHBoxLayout()
        hlayout2.addSpacing(25)
        hlayout2.addWidget(self.text_box)
        hlayout2.addSpacing(25)

        hlayout3 = QHBoxLayout()
        hlayout3.addSpacing(25)
        hlayout3.addWidget(self.text_company)
        hlayout3.addSpacing(25)

        vlayout = QVBoxLayout()
        vlayout.addSpacing(25)
        vlayout.addLayout(hlayout)
        vlayout.addSpacing(20)
        vlayout.addLayout(hlayout2)
        vlayout.addSpacing(30)
        vlayout.addLayout(hlayout3)
        vlayout.addSpacing(0)
        vlayout.setContentsMargins(0, 0, 0, 0)
        self.setLayout(vlayout)

        self.show()

    # 初始化信号槽
    def init_connect(self):
        self.close_button.clicked.connect(self.slot_close_button_clicked)

    def slot_close_button_clicked(self):
        self.text_company.clear()
        self.text_box.clear()
        self.hide()

    # 鼠标点击、释放和移动事件
    def mousePressEvent(self, event):
        if (event.button() == Qt.LeftButton):
            self.mouse_press = True
            self.drag_pos = event.globalPos() - self.pos()
            event.accept()

    def mouseReleaseEvent(self, event):
        self.mouse_press = False
        self.setWindowOpacity(1)

    def mouseMoveEvent(self, event):
        if (self.mouse_press):
            self.move_pos = event.globalPos()
            self.move(self.move_pos - self.drag_pos)
            self.setWindowOpacity(1)
            event.accept()

    def center(self):
        qr = self.frameGeometry()
        cp = QDesktopWidget().availableGeometry().center()
        qr.moveCenter(cp)
        self.move(qr.topLeft())
